\name{dataDIVAT}
\alias{dataDIVAT}
\docType{data}
\title{
A sample of the DIVAT cohort.
}
\description{
A data frame with 5943 French kidney transplant recipients (KTR) from the DIVAT cohort. As described in \code{eSemiMarkov package}, the KTR evolution can be described according to the 4-state structure. X=2 represents the acute rejection episode, X=3 represents the definitive return to dialysis and X=4 represents the death. These times can be right-censored. A vector of covariates is also collected at the transplantation.
}
\usage{data(dataDIVAT)}
\format{
 A data frame with 5943 observations (rows) with the 7 following variables (columns):
\tabular{rl}{
\code{trajectory} \tab this numeric vector represents the sequences of states of the recipient. \cr											
\code{time1} \tab this numeric vector represents the time-to-first event in days, i.e. the time between \cr
	\tab the transplantation and the first clinical event (acute rejection episode, return to \cr
	\tab  dialysis, or recipient death with a functioning graft), or the time-to-censoring if \cr
	\tab applicable (X=1 at the last follow-up). \cr
\code{time2} \tab this numeric vector represents the time-to-second event in days, i.e. the time between \cr
	\tab the transplantation and the second clinical event (return to dialysis or recipient death \cr
	\tab with a functioning graft), or the the time-to-censoring if applicable (X=2 at the last \cr
	\tab follow-up). \cr
\code{ageR} \tab this numeric vector represents the age of the recipient at the transplantation (in years).\cr
\code{sexR} \tab this character vector represents the gender of the recipient (\code{male} or \code{female}). \cr
\code{year.tx} \tab this numeric vector represents the calendar year of the transplantation. \cr
\code{z} \tab this numeric vector represents the explicative variable under interest, i.e. the delayed \cr
	\tab graft function (1=yes, 0=no). \cr
}
}
\details{
The immunology and nephrology department of the Nantes University hospital constituted a data bank with the monitoring of medical records for kidney and/or pancreas transplant recipients. Here is a sample of 5943 patients from this DIVAT cohort. A vector of covariates, all measured at the transplantation, is collected for each patient.
}
\source{
URL: http://www.divat.fr/
}
\examples{
data(dataDIVAT)

### a description of transitions
table(dataDIVAT$trajectory)

### patient-graft survival (first event between the return to dialysis and the patient 
### death with a functioning graft)

dataDIVAT$failure<-1*(dataDIVAT$trajectory!=1 & dataDIVAT$trajectory!=12)

dataDIVAT$time_to_failure<-NA
dataDIVAT$time_to_failure<-ifelse(dataDIVAT$trajectory \%in\% c(1,12,13,14),
dataDIVAT$time1,dataDIVAT$time1+dataDIVAT$time2)

plot(survfit(Surv(time_to_failure/365.24, failure) ~ 1 , data=dataDIVAT), mark.time=FALSE, 
      xlim=c(0,12), ylim=c(0,1), cex=1.5, col=1, lwd=2, lty=1, 
      xlab="Times after the transplantation (years)", 
      ylab="Patient-graft survival")

}
\keyword{datasets}
\keyword{France}
\keyword{DIVAT}
